# namekoplus

A lightweight Python distributed microservice solution

## Document

[中文文档](https://doc.bearcatlog.com/)

## Command Line Tool Usage

### Checkout Command

```shell
namekoplus --help
```

### Initialize a nameko service from templates

```shell
namekoplus init --directory <dir_name> --type <template_type>
```
